"""
Model configuration module
"""

from gptmed.model.configs.model_config import (
    ModelConfig,
    get_tiny_config,
    get_small_config,
    get_medium_config,
)

__all__ = [
    "ModelConfig",
    "get_tiny_config",
    "get_small_config",
    "get_medium_config",
]
